@@ -26,24 +26,26 @@ This module contains classes and functions associated to the interpolation of th
 import logging
 import math
 from abc import ABCMeta, abstractmethod
-from typing import Tuple
+from typing import Tuple, Dict
 
 import numpy as np
 import xarray as xr
 from numba import njit
 
 import pandora.constants as cst
+from pandora.img_tools import find_valid_neighbors
 
 
-class AbstractInterpolation():
+class AbstractInterpolation:
     """
     Abstract Interpolation class
     """
+
     __metaclass__ = ABCMeta
 
-    interpolation_methods_avail = {}
+    interpolation_methods_avail: Dict = {}
 
-    def __new__(cls, **cfg: dict) -> object:
+    def __new__(cls, **cfg: dict):
         """
         Return the plugin associated with the interpolated_disparity given in the configuration
 
@@ -51,24 +53,33 @@ class AbstractInterpolation():
         :type cfg: dictionary
         """
         if cls is AbstractInterpolation:
-            if isinstance(cfg['interpolated_disparity'], str):
+            if isinstance(cfg["interpolated_disparity"], str):
                 try:
                     return super(AbstractInterpolation, cls).__new__(
-                        cls.interpolation_methods_avail[cfg['interpolated_disparity']])
+                        cls.interpolation_methods_avail[cfg["interpolated_disparity"]]
+                    )
                 except KeyError:
-                    logging.error('No interpolation method named % supported', cfg['interpolated_disparity'])
+                    logging.error(
+                        "No interpolation method named % supported",
+                        cfg["interpolated_disparity"],
+                    )
                     raise KeyError
             else:
-                if isinstance(cfg['interpolated_disparity'], unicode): # pylint: disable=undefined-variable
+                if isinstance(cfg["interpolated_disparity"], unicode):  # type: ignore # pylint: disable=undefined-variable
                     # creating a plugin from registered short name given as unicode (py2 & 3 compatibility)
                     try:
                         return super(AbstractInterpolation, cls).__new__(
-                            cls.interpolation_methods_avail[cfg['interpolated_disparity'].encode('utf-8')])
+                            cls.interpolation_methods_avail[cfg["interpolated_disparity"].encode("utf-8")]
+                        )
                     except KeyError:
-                        logging.error('No interpolation method named % supported', cfg['interpolated_disparity'])
+                        logging.error(
+                            "No interpolation method named % supported",
+                            cfg["interpolated_disparity"],
+                        )
                         raise KeyError
         else:
             return super(AbstractInterpolation, cls).__new__(cls)
+        return None
 
     @classmethod
     def register_subclass(cls, short_name: str):
@@ -97,11 +108,16 @@ class AbstractInterpolation():
         Describes the disparity interpolation method for the validation step
         :return: None
         """
-        print('Disparity interpolation method description for the validation step')
+        print("Disparity interpolation method description for the validation step")
 
     @abstractmethod
-    def interpolated_disparity(self, left: xr.Dataset, img_left: xr.Dataset = None, img_right: xr.Dataset = None,
-                               cv: xr.Dataset = None) -> None:
+    def interpolated_disparity(
+        self,
+        left: xr.Dataset,
+        img_left: xr.Dataset = None,
+        img_right: xr.Dataset = None,
+        cv: xr.Dataset = None,
+    ) -> None:
         """
         Interpolation of the left disparity map to resolve occlusion and mismatch conflicts.
 
@@ -130,11 +146,11 @@ class AbstractInterpolation():
         """
 
 
-@AbstractInterpolation.register_subclass('mc-cnn')
+@AbstractInterpolation.register_subclass("mc-cnn")
 class McCnnInterpolation(AbstractInterpolation):
     """
-        McCnnInterpolation class allows to perform the interpolation of the disparity map
-        """
+    McCnnInterpolation class allows to perform the interpolation of the disparity map
+    """
 
     def __init__(self, **cfg: dict) -> None:
         """
@@ -159,10 +175,15 @@ class McCnnInterpolation(AbstractInterpolation):
         Describes the disparity interpolation method
         :return: None
         """
-        print('MC-CNN interpolation method')
+        print("MC-CNN interpolation method")
 
-    def interpolated_disparity(self, left: xr.Dataset, img_left: xr.Dataset = None, img_right: xr.Dataset = None,
-                               cv: xr.Dataset = None) -> None:
+    def interpolated_disparity(
+        self,
+        left: xr.Dataset,
+        img_left: xr.Dataset = None,
+        img_right: xr.Dataset = None,
+        cv: xr.Dataset = None,
+    ) -> None:
         """
         Interpolation of the left disparity map to resolve occlusion and mismatch conflicts.
 
@@ -190,12 +211,16 @@ class McCnnInterpolation(AbstractInterpolation):
         :return: None
         """
 
-        left['disparity_map'].data, left['validity_mask'].data = \
-            self.interpolate_occlusion_mc_cnn(left['disparity_map'].data, left['validity_mask'].data)
-        left['disparity_map'].data, left['validity_mask'].data = \
-            self.interpolate_mismatch_mc_cnn(left['disparity_map'].data, left['validity_mask'].data)
+        (
+            left["disparity_map"].data,
+            left["validity_mask"].data,
+        ) = self.interpolate_occlusion_mc_cnn(left["disparity_map"].data, left["validity_mask"].data)
+        (
+            left["disparity_map"].data,
+            left["validity_mask"].data,
+        ) = self.interpolate_mismatch_mc_cnn(left["disparity_map"].data, left["validity_mask"].data)
 
-        left.attrs['interpolated_disparity'] = 'mc-cnn'
+        left.attrs["interpolated_disparity"] = "mc-cnn"
 
     @staticmethod
     @njit()
@@ -229,7 +254,7 @@ class McCnnInterpolation(AbstractInterpolation):
                     # interpolate occlusion by moving left until we find a position labeled correct
 
                     #  valid pixels mask
-                    msk = (valid[col, 0:row + 1] & cst.PANDORA_MSK_PIXEL_INVALID) == 0
+                    msk = (valid[col, 0 : row + 1] & cst.PANDORA_MSK_PIXEL_INVALID) == 0
                     # Find the first valid pixel
                     msk = msk[::-1]
                     arg_valid = np.argmax(msk)
@@ -281,8 +306,26 @@ class McCnnInterpolation(AbstractInterpolation):
         ncol, nrow = disp.shape
 
         # 16 directions : [row, col]
-        dirs = np.array([[0., 1.], [-0.5, 1.], [-1., 1.], [-1., 0.5], [-1., 0.], [-1., -0.5], [-1., -1.], [-0.5, -1.],
-                         [0., -1.], [0.5, -1.], [1., -1.], [1., -0.5], [1., 0.], [1., 0.5], [1., 1.], [0.5, 1.]])
+        dirs = np.array(
+            [
+                [0.0, 1.0],
+                [-0.5, 1.0],
+                [-1.0, 1.0],
+                [-1.0, 0.5],
+                [-1.0, 0.0],
+                [-1.0, -0.5],
+                [-1.0, -1.0],
+                [-0.5, -1.0],
+                [0.0, -1.0],
+                [0.5, -1.0],
+                [1.0, -1.0],
+                [1.0, -0.5],
+                [1.0, 0.0],
+                [1.0, 0.5],
+                [1.0, 1.0],
+                [0.5, 1.0],
+            ]
+        )
 
         # Maximum path length
         max_path_length = max(nrow, ncol)
@@ -320,11 +363,11 @@ class McCnnInterpolation(AbstractInterpolation):
         return out_disp, out_val
 
 
-@AbstractInterpolation.register_subclass('sgm')
+@AbstractInterpolation.register_subclass("sgm")
 class SgmInterpolation(AbstractInterpolation):
     """
-        SgmInterpolation class allows to perform the interpolation of the disparity map
-        """
+    SgmInterpolation class allows to perform the interpolation of the disparity map
+    """
 
     def __init__(self, **cfg: dict) -> None:
         """
@@ -349,10 +392,15 @@ class SgmInterpolation(AbstractInterpolation):
         Describes the disparity interpolation method
         :return: None
         """
-        print('SGM interpolation method')
+        print("SGM interpolation method")
 
-    def interpolated_disparity(self, left: xr.Dataset, img_left: xr.Dataset = None, img_right: xr.Dataset = None,
-                               cv: xr.Dataset = None) -> None:
+    def interpolated_disparity(
+        self,
+        left: xr.Dataset,
+        img_left: xr.Dataset = None,
+        img_right: xr.Dataset = None,
+        cv: xr.Dataset = None,
+    ) -> None:
         """
         Interpolation of the left disparity map to resolve occlusion and mismatch conflicts.
 
@@ -380,15 +428,19 @@ class SgmInterpolation(AbstractInterpolation):
         :return: None
         """
 
-        left['disparity_map'].data, left['validity_mask'].data = self.interpolate_mismatch_sgm(
-            left['disparity_map'].data,
-            left['validity_mask'].data)
-        left['disparity_map'].data, left['validity_mask'].data = self.interpolate_occlusion_sgm(
-            left['disparity_map'].data,
-            left['validity_mask'].data)
-        left.attrs['interpolated_disparity'] = 'sgm'
+        (
+            left["disparity_map"].data,
+            left["validity_mask"].data,
+        ) = self.interpolate_mismatch_sgm(left["disparity_map"].data, left["validity_mask"].data)
+        (
+            left["disparity_map"].data,
+            left["validity_mask"].data,
+        ) = self.interpolate_occlusion_sgm(left["disparity_map"].data, left["validity_mask"].data)
+        left.attrs["interpolated_disparity"] = "sgm"
 
-    def interpolate_occlusion_sgm(self, disp: np.ndarray, valid: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
+    @staticmethod
+    @njit()
+    def interpolate_occlusion_sgm(disp: np.ndarray, valid: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
         """
         Interpolation of the left disparity map to resolve occlusion conflicts.
         Interpolate occlusion by moving by selecting
@@ -418,7 +470,7 @@ class SgmInterpolation(AbstractInterpolation):
             for row in range(nrow):
                 # Occlusion
                 if (valid[col, row] & cst.PANDORA_MSK_PIXEL_OCCLUSION) != 0:
-                    valid_neighbors = self.find_valid_neighbors(dirs, disp, valid, row, col)
+                    valid_neighbors = find_valid_neighbors(dirs, disp, valid, row, col)
 
                     # Returns the indices that would sort the absolute array
                     # The absolute value is used to search for the right value closest to 0
@@ -432,7 +484,9 @@ class SgmInterpolation(AbstractInterpolation):
                     out_val[col, row] += cst.PANDORA_MSK_PIXEL_FILLED_OCCLUSION
         return out_disp, out_val
 
-    def interpolate_mismatch_sgm(self, disp: np.ndarray, valid: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
+    @staticmethod
+    @njit()
+    def interpolate_mismatch_sgm(disp: np.ndarray, valid: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
         """
         Interpolation of the left disparity map to resolve mismatch conflicts. Interpolate mismatch by finding the
         nearest correct pixels in 8 different directions and use the median of their disparities.
@@ -464,14 +518,21 @@ class SgmInterpolation(AbstractInterpolation):
                 if valid[col, row] & cst.PANDORA_MSK_PIXEL_MISMATCH != 0:
 
                     # Mismatched pixel areas that are direct neighbors of occluded pixels are treated as occlusions
-                    if np.sum(valid[max(0, col - 1):min(ncol - 1, col + 1) + 1,
-                              max(0, row - 1):min(nrow - 1, row + 1) + 1] &
-                              cst.PANDORA_MSK_PIXEL_OCCLUSION) != 0:
+                    if (
+                        np.sum(
+                            valid[
+                                max(0, col - 1) : min(ncol - 1, col + 1) + 1,
+                                max(0, row - 1) : min(nrow - 1, row + 1) + 1,
+                            ]
+                            & cst.PANDORA_MSK_PIXEL_OCCLUSION
+                        )
+                        != 0
+                    ):
                         out_val[col, row] -= cst.PANDORA_MSK_PIXEL_MISMATCH
                         out_val[col, row] += cst.PANDORA_MSK_PIXEL_OCCLUSION
 
                     else:
-                        valid_neighbors = self.find_valid_neighbors(dirs, disp, valid, row, col)
+                        valid_neighbors = find_valid_neighbors(dirs, disp, valid, row, col)
 
                         # Median of the 8 pixels
                         out_disp[col, row] = np.nanmedian(valid_neighbors)
@@ -480,44 +541,3 @@ class SgmInterpolation(AbstractInterpolation):
                         out_val[col, row] += cst.PANDORA_MSK_PIXEL_FILLED_MISMATCH
 
         return out_disp, out_val
-
-    @staticmethod
-    @njit()
-    def find_valid_neighbors(dirs: np.ndarray, disp: np.ndarray, valid: np.ndarray,
-                             row: int, col: int):
-        """
-        :param dirs: directions
-        :type dirs: 2D np.array (row, col)
-        :param disp: disparity map
-        :type disp: 2D np.array (row, col)
-        :param valid: validity mask
-        :type valid: 2D np.array (row, col)
-        :param row: row current value
-        :type row: int
-        :param col: col current value
-        :type col: int
-        :return: valid neighbors
-        :rtype: 2D np.array
-        """
-        ncol, nrow = disp.shape
-        # Maximum path length
-        max_path_length = max(nrow, ncol)
-        # For each directions
-        valid_neighbors = np.zeros(8, dtype=np.float32)
-        for direction in range(8):
-            # Find the first valid pixel in the current path
-            tmp_row = row
-            tmp_col = col
-            for i in range(max_path_length):  # pylint: disable= unused-variable
-                tmp_row += dirs[direction][0]
-                tmp_col += dirs[direction][1]
-
-                # Edge of the image reached: there is no valid pixel in the current path
-                if (tmp_col < 0) | (tmp_col >= ncol) | (tmp_row < 0) | (tmp_row >= nrow):
-                    valid_neighbors[direction] = np.nan
-                    break
-                # First valid pixel
-                if (valid[tmp_col, tmp_row] & cst.PANDORA_MSK_PIXEL_INVALID) == 0:
-                    valid_neighbors[direction] = disp[tmp_col, tmp_row]
-                    break
-        return valid_neighbors
